@@ -1,4 +1,5 @@
 import subprocess
+import locale
 
 
 def run_command(exec_cmd: str, current_working_dir: str) -> str:
@@ -7,4 +8,4 @@ def run_command(exec_cmd: str, current_working_dir: str) -> str:
                           stdout=subprocess.PIPE,
                           stderr=subprocess.STDOUT,
                           cwd=current_working_dir)
-    return proc.stdout.decode("utf8")
+    return proc.stdout.decode(locale.getpreferredencoding())
